@@ -1,6 +1,6 @@
 /*
- $Id: unicode.h 8186 2011-02-02 14:14:17Z sloot $
- $URL: https://svn.ilk.uvt.nl/svn/trunk/sources/ucto/trunk/include/ucto/unicode.h $
+ $Id: unicode.h 13508 2011-11-02 15:44:17Z sloot $
+ $URL: https://ilk.uvt.nl/svn/sources/ucto/trunk/include/ucto/unicode.h $
   Copyright (c) 1998 - 2011
   ILK  -  Tilburg University
   CNTS -  University of Antwerp
@@ -37,10 +37,6 @@
 #include "unicode/unistr.h"
 #include "unicode/normlzr.h"
 
-// add two convenient fuctiond to the std:: namespace
-UnicodeString UTF8ToUnicode( const std::string& );
-std::string UnicodeToUTF8( const UnicodeString& );
-
 namespace Tokenizer {
 
   class UnicodeNormalizer {
