@@ -1,6 +1,6 @@
 /*
-  $Id: ucto.cxx 8936 2011-03-17 15:48:54Z sloot $
-  $URL: https://svn.ilk.uvt.nl/svn/trunk/sources/ucto/trunk/src/ucto.cxx $
+  $Id: ucto.cxx 13698 2011-12-14 11:10:00Z sloot $
+  $URL: https://ilk.uvt.nl/svn/sources/ucto/trunk/src/ucto.cxx $
   Copyright (c) 1998 - 2011
   ILK  -  Tilburg University
   CNTS -  University of Antwerp
@@ -25,14 +25,15 @@
   or send mail to:
       Timbl@uvt.nl
 */
+#include <cstdlib>
 #include <cstring>
 #include <getopt.h>
 #include <string>
 #include <iostream>
 #include <fstream>
 #include "ucto/tokenize.h"
+#include "libfolia/folia.h"
 #include <unistd.h>
-#include "config.h"
 
 using namespace std;
 using namespace Tokenizer;
@@ -51,14 +52,16 @@ void usage(){
        << "\t-u              - Convert to all uppercase" << endl       
        << "\t-n              - One sentence per line (output)" << endl
        << "\t-m              - One sentence per line (input)" << endl
-       << "\t-V              - Verbose mode" << endl
+       << "\t-v              - Verbose mode" << endl
        << "\t-s <string>     - End-of-Sentence marker (default: <utt>)" << endl
+       << "\t--passthru      - Don't tokenize, but perform input decoding and simple token role detection" << endl
        << "\t-P              - Disable paragraph detection" << endl
        << "\t-S              - Disable sentence detection!" << endl
-       << "\t-Q              - Disable quote detection" << endl
-       << "\t-v              - Show version information" << endl
+       << "\t-Q              - Enable quote detection (experimental)" << endl
+       << "\t-V              - Show version information" << endl
        << "\t-x <DocID>      - Output FoLiA XML, use the specified Document ID" << endl
-       << "\t                  (-x disables usage of most other options: -nulPQVsS)" << endl;
+       << "\t-F              - Input file is in FoLiA XML. All untokenised sentences will be tokenised." << endl
+       << "\t                  (-x and -F disable usage of most other options: -nulPQVsS)" << endl;
 }
 
 int main( int argc, char *argv[] ){
@@ -68,16 +71,16 @@ int main( int argc, char *argv[] ){
   bool sentenceperlineoutput = false;
   bool sentenceperlineinput = false;
   bool paragraphdetection = true;
-  bool quotedetection = true;
+  bool quotedetection = false;
   bool dofiltering = true;
   bool splitsentences = true;
+  bool xmlin = false;
   bool xmlout = false;
   bool verbose = false;
   string eosmarker = "<utt>";
   string docid = "untitleddoc";
   string normalization = "NFC";
   string inputEncoding = "UTF-8";
-  string cdir = string(SYSCONF_PATH) + "/ucto/";
   string cfile = "tokconfig-en";
   string ifile;
   string ofile;
@@ -92,7 +95,7 @@ int main( int argc, char *argv[] ){
   bool passThru = false;
   try {
     while ((opt = getopt_long( argc, argv, 
-			       "d:e:fhlPQunmN:vVSL:c:s:x:",
+			       "d:e:fhlPQunmN:vVSL:c:s:x:F",
 			       longOpts, &longOpt )) != -1) {
       switch (opt)
 	{  
@@ -100,8 +103,9 @@ int main( int argc, char *argv[] ){
 	case 'd': debug = stringTo<int>(optarg); break;
 	case 'e': inputEncoding = optarg; break;
 	case 'f': dofiltering = false; break;
+	case 'F': xmlin = true; break;
 	case 'P': paragraphdetection = false; break;
-	case 'Q': quotedetection = false; break;
+	case 'Q': quotedetection = true; break;
 	case 'c': c_file = optarg; break;
 	case 's': eosmarker = optarg; break;
 	case 'S': splitsentences = false; break;
@@ -109,34 +113,37 @@ int main( int argc, char *argv[] ){
 	case 'u': touppercase = true; break;
 	case 'l': tolowercase = true; break;
 	case 'n': sentenceperlineoutput = true; break;
-    case 'm': sentenceperlineinput = true; break;
+	case 'm': sentenceperlineinput = true; break;
 	case 'N': normalization = optarg; break;
-	case 'V': verbose = true; break;
-	case 'v': cout << "Ucto - Unicode Tokenizer - version " << VERSION << endl << "(c) ILK 2009 - 2011, Induction of Linguistic Knowledge Research Group, Tilburg University" << endl << "Licensed under the GNU General Public License v3" << endl; return 0;
+	case 'v': verbose = true; break;
+	case 'V': cout << "Ucto - Unicode Tokenizer - version " << Version() << endl << "(c) ILK 2009 - 2011, Induction of Linguistic Knowledge Research Group, Tilburg University" << endl << "Licensed under the GNU General Public License v3" << endl; 
+	  cout << "based on [" << folia::VersionName() << "]" << endl;
+	  return EXIT_SUCCESS;
 	case 'x': xmlout = true; docid = optarg; break;
-	default: usage(); return 0;
+	default: usage(); return EXIT_SUCCESS;
 	}
     }
   }
   catch ( exception &e ){
     cerr << "Error in option '" << char(opt) << "' : " << e.what() << endl << endl;
     usage();
-    return 0;
+    return EXIT_FAILURE;
   }
 
   if ( !passThru ){
     if ( !c_file.empty() && !L_file.empty()) {
       cerr << "Error: -L and -c options conflict. Use only one of them." << endl;
-      return 2;
+      return EXIT_FAILURE;
     }
-    if ( !c_file.empty() )
+    if ( !c_file.empty() ){
       cfile = c_file;
+    }
     else if ( !L_file.empty() )
       cfile = L_file;
     else { 
       cerr << "Error: Please specify either a language (-L) or a configuration file (-c)" << endl;
       usage();
-      return 2;
+      return EXIT_FAILURE;
     }
   }
   
@@ -145,34 +152,36 @@ int main( int argc, char *argv[] ){
   
   if ((!ifile.empty()) && (ifile == ofile)) {
     cerr << "Error: Output file equals input file! Courageously refusing to start..."  << endl;
-    return 2;
+    return EXIT_FAILURE;
   }
 
   if ( !passThru ){
-    cerr << "configdir = " << cdir << endl;
     cerr << "configfile = " << cfile << endl;
   }
   cerr << "inputfile = "  << ifile << endl;
   cerr << "outputfile = " << ofile << endl;
-
+  
   istream *IN = 0;
-  if ( ifile.empty() )
-    IN = &cin;
-  else {
-    IN = new ifstream( ifile.c_str() );
-    if ( !IN || !IN->good() ){
-      cerr << "Error: problems opening inputfile " << ifile << endl;
-      cerr << "Courageously refusing to start..."  << endl;
-      return 2;
+  if (!xmlin) {    
+    if ( ifile.empty() )
+      IN = &cin;
+    else {
+      IN = new ifstream( ifile.c_str() );
+      if ( !IN || !IN->good() ){
+	cerr << "Error: problems opening inputfile " << ifile << endl;
+	cerr << "Courageously refusing to start..."  << endl;
+	return EXIT_FAILURE;
+      }
     }
   }
+  
   ostream *OUT = 0;
   if ( ofile.empty() )
     OUT = &cout;
   else {
     OUT = new ofstream( ofile.c_str() );
   }
-
+  
   try {  
     TokenizerClass tokenizer;
     // set debug first, so init() can be debugged too
@@ -182,7 +191,7 @@ int main( int argc, char *argv[] ){
     }
     else {
       // init exept for passthru mode
-      tokenizer.init( cdir, cfile );
+      tokenizer.init( cfile );
     }
 
     tokenizer.setEosMarker( eosmarker );
@@ -198,16 +207,24 @@ int main( int argc, char *argv[] ){
     tokenizer.setInputEncoding( inputEncoding );
     tokenizer.setFiltering(dofiltering);
     tokenizer.setXMLOutput(xmlout, docid);
+    tokenizer.setXMLInput(xmlin);
 
-    tokenizer.tokenize(IN,OUT);
-    if ( OUT != &cout )
-      delete OUT;
-    if ( IN != &cin )
-      delete IN;
+    if (xmlin) {
+      folia::Document doc;
+      doc.readFromFile(ifile);
+      tokenizer.tokenize(doc);
+      *OUT << doc << endl;
+    } else {
+      tokenizer.tokenize(IN,OUT);
+      if ( OUT != &cout )
+	delete OUT;
+      if ( IN != &cin )
+	delete IN;
+    }
   }
   catch ( exception &e ){
     cerr << e.what() << endl;
-    return 0;
+    return EXIT_FAILURE;
   }
   
 }
